AudioDeviceEvent class
Constructors
- AudioDeviceEvent({required AudioDeviceEventKind kind, required AudioDeviceFlow flow, required DateTime timestamp, String? deviceId, String? deviceName, required bool isDefault, required bool isSelected})
-
const
- AudioDeviceEvent.fromMap(Map map)
-
factory
Properties
- deviceId → String?
-
final
- deviceName → String?
-
final
- flow → AudioDeviceFlow
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDefault → bool
-
final
- isSelected → bool
-
final
- kind → AudioDeviceEventKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited