AudioLevels class
Constructors
- AudioLevels({required double leftPeak, required double rightPeak, required DateTime timestamp, String? outputDeviceId, String? outputDeviceName, String? inputDeviceId, String? inputDeviceName})
-
const
- AudioLevels.fromMap(Map map)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputDeviceId → String?
-
final
- inputDeviceName → String?
-
final
- leftPeak → double
-
final
- outputDeviceId → String?
-
final
- outputDeviceName → String?
-
final
- rightPeak → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited