MethodChannelSystemAudioMeter class

An implementation of SystemAudioMeterPlatform that uses method channels.

Inheritance

Properties

deviceEventChannel EventChannel
final
deviceEvents Stream<AudioDeviceEvent>
no setteroverride
eventChannel EventChannel
final
hashCode int
The hash code for this object.
no setterinherited
inputEventChannel EventChannel
final
inputLevels Stream<AudioLevels>
no setteroverride
isInputRunning Future<bool>
no setteroverride
isRunning Future<bool>
no setteroverride
levels Stream<AudioLevels>
no setteroverride
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCurrentInputDevice() Future<AudioInputDevice?>
override
getCurrentOutputDevice() Future<AudioOutputDevice?>
override
getInputDevices() Future<List<AudioInputDevice>>
override
getOutputDevices() Future<List<AudioOutputDevice>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setInputDevice(String? deviceId) Future<void>
override
setOutputDevice(String? deviceId) Future<void>
override
start() Future<void>
override
startInput() Future<void>
override
stop() Future<void>
override
stopInput() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited